/*******************************************************************************
********************************************************************************

   COPYRIGHT  2002 Concept 2

   Contains confidential and proprietary information which may not be copied,
   disclosed or used by others except as expressly authorized in writing
   by Concept 2.

   tk_reg.cpp     Source code for the Registry management toolkit functions

   About:         This module contains the implementation of the Registry
                  management toolkit functions of the PM3 Tester in the C2PM3TEST project.

   Target:        Win32 Compatible

   Written for:   Concept 2
                  105 Industrial Park Drive
                  Morrisville, VT 05661
                  802-888-5225 (Voice)
                  802-888-6331 (Fax)

   Contacts:      Scott Hamilton 
                  802-888-5226 x3062 (Voice)
                  scotth@concept2.com

   Written by:    Rob Macklin
                  Microprocessor Designs, Inc.
                  65 Longmeadow Drive
                  PO Box 160
                  Shelburne, VT 05482
                  http://www.updesigns.com

   $Revision: 3 $

--------------------------------------------------------------------------------
   $Log: /Liquid Measurement Systems/LMCH47F/Signal Conditioner/pc_src/Common/tk_reg.cpp $
 * 
 * 3     1/24/05 4:23p Jpiet
 * Changed to new DLLs (LMSCH47CmdDll and LMSCH47AppDll)
 * 
 * 2     1/20/05 8:33a Jpiet
 * Adjustment of DLL headers path to build successfully in Visual Studio
 * 
 * 1     11/11/04 10:39a Rmack
 * Initial check-in.
 * 
 * 2     3/19/03 8:57a Kprei
 * Added acceptance test functionality and calibration file logging
 * capability.
 * 
 * 1     2/26/03 12:00p Kprei
 * 
 * 1     2/26/03 11:17a Rmack
 * Initial check-in
 * 
 * 
********************************************************************************
*******************************************************************************/
#include "stdafx.h"
#include "windows.h"
#include <stdio.h>
#include "compiler.h"
#include "pc_error.h"
#include "tk_reg.h"

/* Define local variables */
static HKEY RegKey = 0;


/****************************************************************************
   tkreg_init

   About:      Initializes the Registry Management Toolkit functions
               The specified key is opened or created

   Inputs:     INT8_T *    keyname     Name of registry key to open or create

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_init(INT8_T * keyname)
{
   ERRCODE_T ecode = NO_ERR;
   DWORD Disposition;

	LONG retCode;
   /* Close the registry key if one is open */
   if (RegKey)
   {
      TKREG_SHUTDOWN_M();
   }
   if ( retCode = RegCreateKeyEx(
         HKEY_CURRENT_USER,(LPCTSTR) keyname,
         0,NULL,REG_OPTION_NON_VOLATILE,KEY_ALL_ACCESS,NULL,
         &RegKey,&Disposition) != ERROR_SUCCESS)
   {
      ecode = TKREG_CANNOT_CREATE_KEY_ERR;
   }

   return(ecode);
}

/****************************************************************************
   tkreg_shutdown

   About:      Stops the Registry Management Toolkit functions
               Any open registry key is closed

   Inputs:     None

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_shutdown()
{
   ERRCODE_T ecode = NO_ERR;
   LONG retVal;
   retVal=RegCloseKey(RegKey);
   RegKey = 0;

   return(ecode);
}

/****************************************************************************
   tkreg_open_string

   About:      Opens a string under the current registry key.  If the string
               does not exist it is initialized with the default string.

   Inputs:     INT8_T *    name        Name of string to open
               INT8_T *    default_str Default string to store if it doesn't exist
               UINT32_T    buf_size    Location holds maximum size of buffer

   Outputs:    INT8_T *    buf         Location to store string

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_open_string(INT8_T * name, INT8_T * default_str, 
                            INT8_T * buf, UINT32_T buf_size)
{
   ERRCODE_T ecode = NO_ERR;
   UINT32_T size = buf_size;

   if (!RegKey)
   {
      ecode = TKREG_NO_OPEN_KEY_ERR;
   }
   else if (RegQueryValueEx(RegKey, (LPTSTR) name, 0, NULL, 
      (LPBYTE) buf,(LPDWORD) &size) != ERROR_SUCCESS)
   {
      size = buf_size;

      if (ecode = TKREG_SET_STRING_M(name, default_str))
      {
      }
      else if (RegQueryValueEx(RegKey, (LPTSTR) name, 0, NULL, 
         (LPBYTE) buf,(LPDWORD) &size) != ERROR_SUCCESS)
      {
         ecode = TKREG_STRING_NOT_FOUND_ERR;
      }
   }

   return(ecode);
}

/****************************************************************************
   tkreg_get_string

   About:      Gets a string under the current registry key.  If the string
               does not exist an error is returned.

   Inputs:     INT8_T *    name        Name of string to open
               UINT32_T    buf_size    Location holds maximum size of buffer

   Outputs:    INT8_T *    buf         Location to store string

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_get_string(INT8_T * name, INT8_T * buf, UINT32_T buf_size)
{
   ERRCODE_T ecode = NO_ERR;
   
   if (!RegKey)
   {
      ecode = TKREG_NO_OPEN_KEY_ERR;
   }
   else if (RegQueryValueEx(RegKey, (LPTSTR) name, 0, NULL, 
      (LPBYTE) buf, (LPDWORD) &buf_size) != ERROR_SUCCESS)
   {
      ecode = TKREG_STRING_NOT_FOUND_ERR;
   }
   
   return(ecode);
}

/****************************************************************************
   tkreg_set_string

   About:      Sets a string under the current registry key.

   Inputs:     INT8_T *    name        Name of string to open
               INT8_T *    buf         String to store in registry

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_set_string(INT8_T * name, INT8_T * buf)
{
   ERRCODE_T ecode = NO_ERR;
   
   if (!RegKey)
   {
      ecode = TKREG_NO_OPEN_KEY_ERR;
   }
   else if (RegSetValueEx(RegKey, (LPCTSTR) name, 0, REG_SZ,
         (CONST BYTE *) buf,strlen((const char *) buf)) != ERROR_SUCCESS)
   {
      ecode = TKREG_STRING_SAVE_ERR;
   }
   
   return(ecode);
}

/****************************************************************************
   tkreg_open_uint32

   About:      Opens a dword under the current registry key.  If the dword
               does not exist it is initialized with the default dword.

   Inputs:     INT8_T *    name        Name of reg key to open
               UINT32_T *  default_val Default value to store if it doesn't exist

   Outputs:    UINT32_T *  retVal         Location to store value

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_open_uint32(INT8_T * name, UINT32_T default_val, 
                            UINT32_T * retVal)
{
   ERRCODE_T ecode = NO_ERR;
//   UINT32_T size = buf_size;
   UINT32_T size = sizeof(UINT32_T);

   if (!RegKey)
   {
      ecode = TKREG_NO_OPEN_KEY_ERR;
   }
   else if (RegQueryValueEx(RegKey, (LPTSTR) name, 0, NULL, 
      (LPBYTE) retVal,(LPDWORD) &size) != ERROR_SUCCESS)
   {
      if (ecode = TKREG_SET_UINT32_M(name, default_val))
      {
      }
      else if (RegQueryValueEx(RegKey, (LPTSTR) name, 0, NULL, 
         (LPBYTE) retVal,(LPDWORD) &size) != ERROR_SUCCESS)
      {
         ecode = TKREG_STRING_NOT_FOUND_ERR;
      }
   }

   return(ecode);
}

/****************************************************************************
   tkreg_get_uint32

   About:      Gets a dword under the current registry key.  If the string
               does not exist an error is returned.

   Inputs:     INT8_T *    name        Name of string to open
               UINT32_T    buf_size    Location holds maximum size of buffer

   Outputs:    INT8_T *    retVal         Location to store string

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_get_uint32(INT8_T * name, UINT32_T * retVal)
{
   ERRCODE_T ecode = NO_ERR;
   UINT32_T size = sizeof(UINT32_T);
   
   if (!RegKey)
   {
      ecode = TKREG_NO_OPEN_KEY_ERR;
   }
   else if (RegQueryValueEx(RegKey, (LPTSTR) name, 0, NULL, 
      (LPBYTE) retVal, (LPDWORD) &size) != ERROR_SUCCESS)
   {
      ecode = TKREG_STRING_NOT_FOUND_ERR;
   }
   
   return(ecode);
}

/****************************************************************************
   tkreg_set_uint32

   About:      Sets a dword under the current registry key.

   Inputs:     INT8_T *    name        Name of string to open
               UINT32_T *  value         Value to store in registry

   Outputs:    None

   Returns:    ERRCODE_T   ecode       Zero if successful
                                       Error code otherwise

****************************************************************************/
ERRCODE_T tkreg_set_uint32(INT8_T * name, UINT32_T value)
{
   ERRCODE_T ecode = NO_ERR;
   LONG errorCode;
   UINT32_T localVal = value;

   if (!RegKey)
   {
      ecode = TKREG_NO_OPEN_KEY_ERR;
   }
   else if ( (errorCode=RegSetValueEx(RegKey, (LPCTSTR) name, 0, REG_DWORD,
         (CONST BYTE *)&localVal,sizeof(UINT32_T))) != ERROR_SUCCESS)
   {
      ecode = TKREG_STRING_SAVE_ERR;
   }
   
   return(ecode);
}

